@@ -1,7 +1,7 @@
 #' @keywords AIRSIS
 #' @export
-#' @title Apply Quality Control to Raw AIRSIS EBAM Dataframe
-#' @param df single site dataframe created by \code{airsis_parseData()}
+#' @title Apply Quality Control to Raw AIRSIS EBAM Tibble
+#' @param tbl single site tibble created by \code{airsis_parseData()}
 #' @param valid_Longitude range of valid Longitude values
 #' @param valid_Latitude range of valid Latitude values
 #' @param remove_Lon_zero flag to remove rows where Longitude == 0
@@ -23,10 +23,10 @@
 #' 
 #' A \code{POSIXct datetime} column (UTC) is also added based on \code{Date.Time.GMT}.
 #' 
-#' @return Cleaned up dataframe of AIRSIS monitor data.
+#' @return Cleaned up tibble of AIRSIS monitor data.
 #' @seealso \code{\link{airsis_qualityControl}}
 
-airsis_EBAMQualityControl <- function(df,
+airsis_EBAMQualityControl <- function(tbl,
                                       valid_Longitude=c(-180,180),
                                       valid_Latitude=c(-90,90),
                                       remove_Lon_zero = TRUE,
@@ -37,14 +37,14 @@ airsis_EBAMQualityControl <- function(df,
                                       valid_Conc = c(-Inf,5.000),
                                       flagAndKeep = FALSE) {
   
-  #   > names(df)
+  #   > names(tbl)
   #    [1] "MasterTable_ID" "Alias"          "Latitude"       "Longitude"      "Date.Time.GMT" 
   #    [6] "COncRT"         "ConcHr"         "Flow"           "W.S"            "W.D"           
   #   [11] "AT"             "RHx"            "RHi"            "BV"             "FT"            
   #   [16] "Alarm"          "Type"           "Serial.Number"  "Version"        "Sys..Volts"    
   #   [21] "TimeStamp"      "PDate"          "monitorName"    "monitorType"
   
-  monitorName <- df$monitorName[1]
+  monitorName <- tbl$monitorName[1]
   
   # ----- Missing Values ------------------------------------------------------
   
@@ -56,21 +56,21 @@ airsis_EBAMQualityControl <- function(df,
     # verb for logging messages
     verb <- "Flagging"
     
-    df$rowID <- as.integer(rownames(df))
+    tbl$rowID <- as.integer(rownames(tbl))
     
-    # duplicate df and add columns for flags
-    dfFlagged <- df
-    dfFlagged$QCFlag_anyBad <- FALSE
-    dfFlagged$QCFlag_reasonCode <- NA
-    dfFlagged$QCFlag_badLon <- FALSE
-    dfFlagged$QCFlag_badLat <- FALSE
-    dfFlagged$QCFlag_badType <- FALSE
-    dfFlagged$QCFlag_badFlow <- FALSE
-    dfFlagged$QCFlag_badAT <- FALSE
-    dfFlagged$QCFlag_badRHi <- FALSE
-    dfFlagged$QCFlag_badConcHr <- FALSE
-    dfFlagged$QCFlag_badDateAndTime <- FALSE
-    dfFlagged$QCFlag_duplicateHr <- FALSE
+    # duplicate tbl and add columns for flags
+    tblFlagged <- tbl
+    tblFlagged$QCFlag_anyBad <- FALSE
+    tblFlagged$QCFlag_reasonCode <- NA
+    tblFlagged$QCFlag_badLon <- FALSE
+    tblFlagged$QCFlag_badLat <- FALSE
+    tblFlagged$QCFlag_badType <- FALSE
+    tblFlagged$QCFlag_badFlow <- FALSE
+    tblFlagged$QCFlag_badAT <- FALSE
+    tblFlagged$QCFlag_badRHi <- FALSE
+    tblFlagged$QCFlag_badConcHr <- FALSE
+    tblFlagged$QCFlag_badDateAndTime <- FALSE
+    tblFlagged$QCFlag_duplicateHr <- FALSE
   } else {
     # verb for logging messages
     verb <- "Discarding"
@@ -80,46 +80,46 @@ airsis_EBAMQualityControl <- function(df,
   
   # Latitude and longitude must be in range
   if ( remove_Lon_zero ) {
-    goodLonMask <- !is.na(df$Longitude) & (df$Longitude >= valid_Longitude[1]) & (df$Longitude <= valid_Longitude[2]) & (df$Longitude != 0)
+    goodLonMask <- !is.na(tbl$Longitude) & (tbl$Longitude >= valid_Longitude[1]) & (tbl$Longitude <= valid_Longitude[2]) & (tbl$Longitude != 0)
   } else {
-    goodLonMask <- !is.na(df$Longitude) & (df$Longitude >= valid_Longitude[1]) & (df$Longitude <= valid_Longitude[2])
+    goodLonMask <- !is.na(tbl$Longitude) & (tbl$Longitude >= valid_Longitude[1]) & (tbl$Longitude <= valid_Longitude[2])
   }
   
   if ( remove_Lat_zero ) {
-    goodLatMask <- !is.na(df$Latitude) & (df$Latitude >= valid_Latitude[1]) & (df$Latitude <= valid_Latitude[2]) & (df$Latitude != 0)
+    goodLatMask <- !is.na(tbl$Latitude) & (tbl$Latitude >= valid_Latitude[1]) & (tbl$Latitude <= valid_Latitude[2]) & (tbl$Latitude != 0)
   } else {    
-    goodLatMask <- !is.na(df$Latitude) & (df$Latitude >= valid_Latitude[1]) & (df$Latitude <= valid_Latitude[2])
+    goodLatMask <- !is.na(tbl$Latitude) & (tbl$Latitude >= valid_Latitude[1]) & (tbl$Latitude <= valid_Latitude[2])
   }
   
   badRows <- !(goodLonMask & goodLatMask)
   badRowCount <- sum(badRows)
   if ( badRowCount > 0 ) {
     logger.info(paste(verb,"%s rows with invalid location information"), badRowCount)
-    badLocations <- paste('(',df$Longitude[badRows],',',df$Latitude[badRows],')',sep='')
+    badLocations <- paste('(',tbl$Longitude[badRows],',',tbl$Latitude[badRows],')',sep='')
     logger.debug("Bad locations: %s", paste0(badLocations, collapse=", "))
     if ( flagAndKeep ) {
       # apply flags
-      dfFlagged$QCFlag_badLon[df$rowID[!goodLonMask]] <- TRUE
-      dfFlagged$QCFlag_badLat[df$rowID[!goodLatMask]] <- TRUE
-      dfFlagged$QCFlag_anyBad <- dfFlagged$QCFlag_anyBad | dfFlagged$QCFlag_badLon | dfFlagged$QCFlag_badLat
+      tblFlagged$QCFlag_badLon[tbl$rowID[!goodLonMask]] <- TRUE
+      tblFlagged$QCFlag_badLat[tbl$rowID[!goodLatMask]] <- TRUE
+      tblFlagged$QCFlag_anyBad <- tblFlagged$QCFlag_anyBad | tblFlagged$QCFlag_badLon | tblFlagged$QCFlag_badLat
       # apply reason codes
-      dfFlagged$QCFlag_reasonCode[df$rowID[!goodLonMask]] <- paste(dfFlagged$QCFlag_reasonCode[df$rowID[!goodLonMask]],"badLon")
-      dfFlagged$QCFlag_reasonCode[df$rowID[!goodLatMask]] <- paste(dfFlagged$QCFlag_reasonCode[df$rowID[!goodLatMask]],"badLat")
+      tblFlagged$QCFlag_reasonCode[tbl$rowID[!goodLonMask]] <- paste(tblFlagged$QCFlag_reasonCode[tbl$rowID[!goodLonMask]],"badLon")
+      tblFlagged$QCFlag_reasonCode[tbl$rowID[!goodLatMask]] <- paste(tblFlagged$QCFlag_reasonCode[tbl$rowID[!goodLatMask]],"badLat")
     }
   }
 
-  df <- df[goodLonMask & goodLatMask,]
+  tbl <- tbl[goodLonMask & goodLatMask,]
   
   # ----- Time ----------------------------------------------------------------
   
   # Add a POSIXct datetime
-  df$datetime <- lubridate::floor_date(lubridate::mdy_hms(df$Date.Time.GMT), unit="hour") - lubridate::dhours(1)
+  tbl$datetime <- lubridate::floor_date(lubridate::mdy_hms(tbl$Date.Time.GMT), unit="hour") - lubridate::dhours(1)
   if ( flagAndKeep ) {
-    # TODO: Unable to get datetime moved from df to dfFlagged without timezone and/or display getting messed up.
+    # TODO: Unable to get datetime moved from tbl to tblFlagged without timezone and/or display getting messed up.
     # For now just duplicating the calculation, then assigning row values to NA after the fact for rows that were
-    # removed from df prior to calculating datetime above. Clean up later if possible.
-    dfFlagged$datetime <- lubridate::floor_date(lubridate::mdy_hms(dfFlagged$Date.Time.GMT), unit="hour") - lubridate::dhours(1)
-    dfFlagged$datetime[ which(!(dfFlagged$rowID %in% df$rowID)) ] <- NA
+    # removed from tbl prior to calculating datetime above. Clean up later if possible.
+    tblFlagged$datetime <- lubridate::floor_date(lubridate::mdy_hms(tblFlagged$Date.Time.GMT), unit="hour") - lubridate::dhours(1)
+    tblFlagged$datetime[ which(!(tblFlagged$rowID %in% tbl$rowID)) ] <- NA
   }
 
   # NOTE: The time above truncates the timestamp to the top of an hour, and then subtracts one hour,
@@ -132,25 +132,25 @@ airsis_EBAMQualityControl <- function(df,
   
   # ----- Type ----------------------------------------------------------------
   
-  goodTypeMask <- !is.na(df$Type) & (df$Type == "PM 2.5")
+  goodTypeMask <- !is.na(tbl$Type) & (tbl$Type == "PM 2.5")
   
   badRows <- !goodTypeMask
   badRowCount <- sum(badRows)
   if ( badRowCount > 0 ) {
     logger.info(paste(verb,"%s rows with invalid Type information"), badRowCount)
-    logger.debug("Bad Types:  %s", paste0(sort(unique(df$Type[badRows]),na.last=TRUE), collapse=", "))
+    logger.debug("Bad Types:  %s", paste0(sort(unique(tbl$Type[badRows]),na.last=TRUE), collapse=", "))
     if ( flagAndKeep ) {
       # apply flags
-      dfFlagged$QCFlag_badType[df$rowID[!goodTypeMask]] <- TRUE
-      dfFlagged$QCFlag_anyBad <- dfFlagged$QCFlag_anyBad | dfFlagged$QCFlag_badType
+      tblFlagged$QCFlag_badType[tbl$rowID[!goodTypeMask]] <- TRUE
+      tblFlagged$QCFlag_anyBad <- tblFlagged$QCFlag_anyBad | tblFlagged$QCFlag_badType
       # apply reason code 
-      dfFlagged$QCFlag_reasonCode[df$rowID[!goodTypeMask]] <- paste(dfFlagged$QCFlag_reasonCode[df$rowID[!goodTypeMask]],"badType")
+      tblFlagged$QCFlag_reasonCode[tbl$rowID[!goodTypeMask]] <- paste(tblFlagged$QCFlag_reasonCode[tbl$rowID[!goodTypeMask]],"badType")
     }
   }
 
-  df <- df[goodTypeMask,]
+  tbl <- tbl[goodTypeMask,]
   
-  if (nrow(df) < 1) {
+  if (nrow(tbl) < 1) {
     logger.warn("No valid PM2.5 data for %s", monitorName)
   }
   
@@ -170,22 +170,22 @@ airsis_EBAMQualityControl <- function(df,
   ###                              ifelse(concQA == 'Negative', 0,
   ###                              ifelse(concQA == 'OK', ConcHr * 1000 , NA)))
   
-  goodFlow <- !is.na(df$Flow) & df$Flow >= valid_Flow[1] & df$Flow <= valid_Flow[2]
-  goodAT <- !is.na(df$AT) & df$AT >= valid_AT[1] & df$AT <= valid_AT[2]
-  goodRHi <- !is.na(df$RHi) & df$RHi >= valid_RHi[1] & df$RHi <= valid_RHi[2]
-  goodConcHr <- !is.na(df$ConcHr) & df$ConcHr >= valid_Conc[1] & df$ConcHr <= valid_Conc[2]
-  gooddatetime <- !is.na(df$datetime) & df$datetime < lubridate::now("UTC") # saw a future date once
+  goodFlow <- !is.na(tbl$Flow) & tbl$Flow >= valid_Flow[1] & tbl$Flow <= valid_Flow[2]
+  goodAT <- !is.na(tbl$AT) & tbl$AT >= valid_AT[1] & tbl$AT <= valid_AT[2]
+  goodRHi <- !is.na(tbl$RHi) & tbl$RHi >= valid_RHi[1] & tbl$RHi <= valid_RHi[2]
+  goodConcHr <- !is.na(tbl$ConcHr) & tbl$ConcHr >= valid_Conc[1] & tbl$ConcHr <= valid_Conc[2]
+  gooddatetime <- !is.na(tbl$datetime) & tbl$datetime < lubridate::now("UTC") # saw a future date once
   
   logger.debug("Flow has %s missing or out of range values", sum(!goodFlow))
-  if (sum(!goodFlow) > 0) logger.debug("Bad Flow values:  %s", paste0(sort(unique(df$Flow[!goodFlow]),na.last=TRUE), collapse=", "))
+  if (sum(!goodFlow) > 0) logger.debug("Bad Flow values:  %s", paste0(sort(unique(tbl$Flow[!goodFlow]),na.last=TRUE), collapse=", "))
   logger.debug("AT has %s missing or out of range values", sum(!goodAT))
-  if (sum(!goodAT) > 0) logger.debug("Bad AT values:  %s", paste0(sort(unique(df$AT[!goodAT]),na.last=TRUE), collapse=", "))
+  if (sum(!goodAT) > 0) logger.debug("Bad AT values:  %s", paste0(sort(unique(tbl$AT[!goodAT]),na.last=TRUE), collapse=", "))
   logger.debug("RHi has %s missing or out of range values", sum(!goodRHi))
-  if (sum(!goodRHi) > 0) logger.debug("Bad RHi values:  %s", paste0(sort(unique(df$RHi[!goodRHi]),na.last=TRUE), collapse=", "))
+  if (sum(!goodRHi) > 0) logger.debug("Bad RHi values:  %s", paste0(sort(unique(tbl$RHi[!goodRHi]),na.last=TRUE), collapse=", "))
   logger.debug("Conc has %s missing or out of range values", sum(!goodConcHr))
-  if (sum(!goodConcHr) > 0) logger.debug("Bad Conc values:  %s", paste0(sort(unique(df$ConcHr[!goodConcHr]),na.last=TRUE), collapse=", "))
+  if (sum(!goodConcHr) > 0) logger.debug("Bad Conc values:  %s", paste0(sort(unique(tbl$ConcHr[!goodConcHr]),na.last=TRUE), collapse=", "))
   logger.debug("datetime has %s missing or out of range values", sum(!gooddatetime))
-  if (sum(!gooddatetime) > 0) logger.debug("Bad datetime values:  %s", paste0(sort(unique(df$datetime[!gooddatetime]),na.last=TRUE), collapse=", "))
+  if (sum(!gooddatetime) > 0) logger.debug("Bad datetime values:  %s", paste0(sort(unique(tbl$datetime[!gooddatetime]),na.last=TRUE), collapse=", "))
   
   goodMask <- goodFlow & goodAT & goodRHi & goodConcHr & gooddatetime
   badQCCount <- sum(!goodMask)
@@ -194,23 +194,23 @@ airsis_EBAMQualityControl <- function(df,
     logger.info(paste(verb,"%s rows because of QC logic"), badQCCount)
     if ( flagAndKeep ) {
       # apply flags
-      dfFlagged$QCFlag_badFlow[df$rowID[!goodFlow]] <- TRUE
-      dfFlagged$QCFlag_badAT[df$rowID[!goodAT]] <- TRUE
-      dfFlagged$QCFlag_badRHi[df$rowID[!goodRHi]] <- TRUE
-      dfFlagged$QCFlag_badConcHr[df$rowID[!goodConcHr]] <- TRUE
-      dfFlagged$QCFlag_badDateAndTime[df$rowID[!gooddatetime]] <- TRUE
-      dfFlagged$QCFlag_anyBad <- (dfFlagged$QCFlag_anyBad | dfFlagged$QCFlag_badFlow | dfFlagged$QCFlag_badAT | 
-                                    dfFlagged$QCFlag_badRHi | dfFlagged$QCFlag_badConcHr | dfFlagged$QCFlag_badDateAndTime)
+      tblFlagged$QCFlag_badFlow[tbl$rowID[!goodFlow]] <- TRUE
+      tblFlagged$QCFlag_badAT[tbl$rowID[!goodAT]] <- TRUE
+      tblFlagged$QCFlag_badRHi[tbl$rowID[!goodRHi]] <- TRUE
+      tblFlagged$QCFlag_badConcHr[tbl$rowID[!goodConcHr]] <- TRUE
+      tblFlagged$QCFlag_badDateAndTime[tbl$rowID[!gooddatetime]] <- TRUE
+      tblFlagged$QCFlag_anyBad <- (tblFlagged$QCFlag_anyBad | tblFlagged$QCFlag_badFlow | tblFlagged$QCFlag_badAT | 
+                                    tblFlagged$QCFlag_badRHi | tblFlagged$QCFlag_badConcHr | tblFlagged$QCFlag_badDateAndTime)
       # apply reason codes
-      dfFlagged$QCFlag_reasonCode[df$rowID[!goodFlow]] <- paste(dfFlagged$QCFlag_reasonCode[df$rowID[!goodFlow]],"badFlow")
-      dfFlagged$QCFlag_reasonCode[df$rowID[!goodAT]] <- paste(dfFlagged$QCFlag_reasonCode[df$rowID[!goodAT]],"badAT")
-      dfFlagged$QCFlag_reasonCode[df$rowID[!goodRHi]] <- paste(dfFlagged$QCFlag_reasonCode[df$rowID[!goodRHi]],"badRHi")
-      dfFlagged$QCFlag_reasonCode[df$rowID[!goodConcHr]] <- paste(dfFlagged$QCFlag_reasonCode[df$rowID[!goodConcHr]],"badConcHr")
-      dfFlagged$QCFlag_reasonCode[df$rowID[!gooddatetime]] <- paste(dfFlagged$QCFlag_reasonCode[df$rowID[!gooddatetime]],"badDateAndTime")
+      tblFlagged$QCFlag_reasonCode[tbl$rowID[!goodFlow]] <- paste(tblFlagged$QCFlag_reasonCode[tbl$rowID[!goodFlow]],"badFlow")
+      tblFlagged$QCFlag_reasonCode[tbl$rowID[!goodAT]] <- paste(tblFlagged$QCFlag_reasonCode[tbl$rowID[!goodAT]],"badAT")
+      tblFlagged$QCFlag_reasonCode[tbl$rowID[!goodRHi]] <- paste(tblFlagged$QCFlag_reasonCode[tbl$rowID[!goodRHi]],"badRHi")
+      tblFlagged$QCFlag_reasonCode[tbl$rowID[!goodConcHr]] <- paste(tblFlagged$QCFlag_reasonCode[tbl$rowID[!goodConcHr]],"badConcHr")
+      tblFlagged$QCFlag_reasonCode[tbl$rowID[!gooddatetime]] <- paste(tblFlagged$QCFlag_reasonCode[tbl$rowID[!gooddatetime]],"badDateAndTime")
     }
   }
   
-  df <- df[goodMask,]
+  tbl <- tbl[goodMask,]
   
   # ----- Duplicate Hours -----------------------------------------------------
   
@@ -219,43 +219,43 @@ airsis_EBAMQualityControl <- function(df,
   # NOTE: want to build in functionality to ensure that the latest is picked if more than one exists
   # NOTE: (for example, if the data is not in order by timestamp for whatever reason)
   
-  dupHrMask <- duplicated(df$datetime,fromLast = TRUE)
+  dupHrMask <- duplicated(tbl$datetime,fromLast = TRUE)
   dupHrCount <- sum(dupHrMask)
   uniqueHrMask <- !dupHrMask
   
   if ( dupHrCount > 0 ) {
     logger.info(paste(verb,"%s duplicate time entries"), dupHrCount)
-    logger.debug("Duplicate Hours (may be >1 per timestamp):  %s", paste0(sort(unique(df$Date.Time.GMT[dupHrMask])), collapse=", "))
+    logger.debug("Duplicate Hours (may be >1 per timestamp):  %s", paste0(sort(unique(tbl$Date.Time.GMT[dupHrMask])), collapse=", "))
     if ( flagAndKeep ) {
       # apply flags
-      dfFlagged$QCFlag_duplicateHr[df$rowID[dupHrMask]] <- TRUE
-      dfFlagged$QCFlag_anyBad <- dfFlagged$QCFlag_anyBad | dfFlagged$QCFlag_duplicateHr
+      tblFlagged$QCFlag_duplicateHr[tbl$rowID[dupHrMask]] <- TRUE
+      tblFlagged$QCFlag_anyBad <- tblFlagged$QCFlag_anyBad | tblFlagged$QCFlag_duplicateHr
       # apply reason code
-      dfFlagged$QCFlag_reasonCode[df$rowID[dupHrMask]] <- paste(dfFlagged$QCFlag_reasonCode[df$rowID[dupHrMask]],"duplicateHr")
+      tblFlagged$QCFlag_reasonCode[tbl$rowID[dupHrMask]] <- paste(tblFlagged$QCFlag_reasonCode[tbl$rowID[dupHrMask]],"duplicateHr")
     }
   }
   
-  df <- df[uniqueHrMask,]
+  tbl <- tbl[uniqueHrMask,]
   
   # ----- More QC -------------------------------------------------------------
   
   # NOTE:  Additional QC would go here
   
   if ( flagAndKeep ) {
-    logger.debug("Retaining %d rows of measurements; %d bad rows flagged", nrow(df), sum(dfFlagged$QCFlag_anyBad))    
+    logger.debug("Retaining %d rows of measurements; %d bad rows flagged", nrow(tbl), sum(tblFlagged$QCFlag_anyBad))    
   } else {
-    logger.debug("Retaining %d rows of validated measurements", nrow(df))
+    logger.debug("Retaining %d rows of validated measurements", nrow(tbl))
   }
   
   # ----- Final cleanup -------------------------------------------------------
   
   if ( flagAndKeep ) {
-    dfFlagged$QCFlag_reasonCode <- stringr::str_sub(dfFlagged$QCFlag_reasonCode, 3)
-    dfFlagged$QCFlag_reasonCode <- stringr::str_trim(dfFlagged$QCFlag_reasonCode)
-    df <- dfFlagged
-    df$rowID <- NULL
+    tblFlagged$QCFlag_reasonCode <- stringr::str_sub(tblFlagged$QCFlag_reasonCode, 3)
+    tblFlagged$QCFlag_reasonCode <- stringr::str_trim(tblFlagged$QCFlag_reasonCode)
+    tbl <- tblFlagged
+    tbl$rowID <- NULL
   }
     
-  return(df)
+  return(tbl)
   
 }
