@@ -13,38 +13,30 @@
 #' \dontrun{
 #' unitIDs <- airsis_availableUnits(20150701, 20151231,
 #'                                  provider='USFS', 
-#'                                  unitType=c('EBAM','ESAM'))
+#'                                  unitTypes=c('EBAM','ESAM'))
 #' }
 
-airsis_availableUnits <- function(startdate=NULL,
-                                  enddate=NULL,
-                                  provider='USFS', unitTypes=c('BAM1020','EBAM','ESAM'),
+airsis_availableUnits <- function(startdate=strftime(lubridate::now(),"%Y010100",tz="UTC"),
+                                  enddate=strftime(lubridate::now(),"%Y%m%d23",tz="UTC"),
+                                  provider='USFS',
+                                  unitTypes=c('BAM1020','EBAM','ESAM'),
                                   baseUrl="http://xxxx.airsis.com/vision/common/CSVExport.aspx?") {
   
-  # Sanity checks
-  if ( is.null(startdate) ) {
-    logger.error("Required parameter 'startdate' is missing")
-    stop(paste0("Required parameter 'startdate' is missing"))
-  }
-  
-  if ( is.null(startdate) ) {
-    logger.error("Required parameter 'enddate' is missing")
-    stop(paste0("Required parameter 'enddate' is missing"))
-  }
-  
-  if ( is.null(unitType) ) {
-    logger.error("Required parameter 'unitID' is missing")
-    stop(paste0("Required parameter 'unitID' is missing"))
-  }
-  
   unitTypes <- toupper(unitTypes)
   
   # Sanity Check
-  if ( !unitType %in% names(AIRSIS$unitTypes) ) {
-    logger.error("Parameter 'unitType=%s' is not recognized", unitType)
-    stop(paste0("Parameter 'unitType=", unitType, "' is not recognized"))
+  badUnitTypes <- setdiff(unitTypes, names(AIRSIS$unitTypes))
+  goodUnitTypes <- intersect(unitTypes, names(AIRSIS$unitTypes))
+  if ( length(badUnitTypes) > 0 ) {
+    badUnitTypesString <- paste0(badUnitTypes, collapse=", ")
+    logger.error("Unrecognized AIRSIS unitType(s): '%s'", badUnitTypesString)
   }
-    
+  if ( length(goodUnitTypes) == 0 ) {
+    err_msg <- paste0("No valid AIRSIS unitType(s): ", paste0(unitTypes, collapse=", "))
+    logger.error(err_msg)
+    stop(err_msg, call. = FALSE)
+  }
+  
   # Get UTC times
   starttime <- parseDatetime(startdate)
   endtime <- parseDatetime(enddate)
@@ -60,8 +52,8 @@ airsis_availableUnits <- function(startdate=NULL,
     
     # Create URL
     url <- paste0(baseUrl, 'utid=', AIRSIS$unitTypes[[unitType]],
-                  '&StartDate=', strftime(starttime, "%F", tz="GMT"),
-                  '&EndDate=', strftime(endtime, "%F", tz="GMT"))
+                  '&StartDate=', strftime(starttime, "%Y-%m-%d", tz="UTC"),
+                  '&EndDate=', strftime(endtime, "%Y-%m-%d", tz="UTC"))
     
     logger.debug("Downloading AIRSIS data from %s", url)
     
