@@ -2,14 +2,14 @@
 #' @export
 #' @title Parse AIRSIS Data String
 #' @param fileString character string containing AIRSIS data as a csv
-#' @description Raw character data from AIRSIS are parsed into a dataframe.
+#' @description Raw character data from AIRSIS are parsed into a tibble.
 #' The incoming \code{fileString}
 #' can be read in directly from AIRSIS using \code{airsis_downloadData()} or from a local
 #' file using \code{readr::read_file()}.
 #' 
 #' The type of monitor represented by this fileString is inferred from the column names
 #' using \code{airsis_identifyMonitorType()} and appropriate column types are assigned.
-#' The character data are then read into a dataframe and augmented in the following ways:
+#' The character data are then read into a tibble and augmented in the following ways:
 #' \enumerate{
 #' \item{Longitude, Latitude and any System Voltage values, which are only present in GPS timestamp rows, are
 #' propagated foward using a last-observation-carry-forward algorithm'}
@@ -22,7 +22,7 @@
 #' @examples
 #' \dontrun{
 #' fileString <- airsis_downloadData(20150701, 20151231, provider='USFS', unitID='1026')
-#' df <- airsis_parseData(fileString)
+#' tbl <- airsis_parseData(fileString)
 #' }
 
 airsis_parseData <- function(fileString) {
@@ -94,10 +94,10 @@ airsis_parseData <- function(fileString) {
   # NOTE:  a single data record as literal data and now a path.
   fakeFile <- paste0(paste0(lines[-1], collapse='\n'),'\n')
 
-  df <- suppressWarnings( readr::read_csv(fakeFile, col_names=columnNames, col_types=columnTypes) )
+  tbl <- suppressWarnings( readr::read_csv(fakeFile, col_names=columnNames, col_types=columnTypes) )
   
   # Print out any problems encountered by readr::read_csv
-  problemsDF <- readr::problems(df)
+  problemsDF <- readr::problems(tbl)
   if ( dim(problemsDF)[1] > 0 ) {
     logger.debug("Records skipped with parsing errors:")
     problems <- utils::capture.output(format(problemsDF))
@@ -107,8 +107,8 @@ airsis_parseData <- function(fileString) {
   }
   
   # Add monitor name and type
-  df$monitorName <- df$Alias
-  df$monitorType <- monitorType
+  tbl$monitorName <- tbl$Alias
+  tbl$monitorType <- monitorType
   
   #     E-Sampler fixes     ---------------------------------------------------
   
@@ -117,10 +117,10 @@ airsis_parseData <- function(fileString) {
     # UnitID=1050 in July, 2016 has extra rows with some sort of metadata in columns Serial.Number and Data.1
     # We remove those here.
     
-    serialNumberMask <- (df$Serial.Number != "") & !is.na(df$Serial.Number)
+    serialNumberMask <- (tbl$Serial.Number != "") & !is.na(tbl$Serial.Number)
     if ( sum(serialNumberMask) > 0 ) {
       logger.debug("Removing %d 'Serial Number' records from raw data", sum(serialNumberMask))
-      df <- df[!serialNumberMask,]
+      tbl <- tbl[!serialNumberMask,]
     }
     
   }
@@ -137,37 +137,37 @@ airsis_parseData <- function(fileString) {
   #     Various fixes     -----------------------------------------------------
   
   # Check to see if any records remain
-  if ( nrow(df) == 0 ) {
+  if ( nrow(tbl) == 0 ) {
     logger.warn("No data remaining after parsing cleanup")
     stop("No data remaining after parsing cleanup", call.=FALSE)
   }
   
   # NOTE:  Latitude, Longitude and Sys..Volts are measured at 6am and 6pm
-  # NOTE:  as separate GPS entries in the dataframe. They need to be carried
+  # NOTE:  as separate GPS entries in the tibble. They need to be carried
   # NOTE:  forward so they appear in all rows.
   
-  gpsMask <- !is.na(df$Longitude)
+  gpsMask <- !is.na(tbl$Longitude)
   
   # Carry data forward to fill in all missing values
-  df$Longitude <- zoo::na.locf(df$Longitude, na.rm=FALSE)
-  df$Latitude <- zoo::na.locf(df$Latitude, na.rm=FALSE)
+  tbl$Longitude <- zoo::na.locf(tbl$Longitude, na.rm=FALSE)
+  tbl$Latitude <- zoo::na.locf(tbl$Latitude, na.rm=FALSE)
   # NOTE: BAM1020s don't have voltage data
-  if ( monitorType == "EBAM" ) df$Sys..Volts <- zoo::na.locf(df$Sys..Volts, na.rm=FALSE)
-  if ( monitorType == "ESAM" ) df$System.Volts <- zoo::na.locf(df$System.Volts, na.rm=FALSE)
+  if ( monitorType == "EBAM" ) tbl$Sys..Volts <- zoo::na.locf(tbl$Sys..Volts, na.rm=FALSE)
+  if ( monitorType == "ESAM" ) tbl$System.Volts <- zoo::na.locf(tbl$System.Volts, na.rm=FALSE)
   
   # Now fill in any missing values at the front end
-  df$Longitude <- zoo::na.locf(df$Longitude, na.rm=FALSE, fromLast=TRUE)
-  df$Latitude <- zoo::na.locf(df$Latitude, na.rm=FALSE, fromLast=TRUE)
+  tbl$Longitude <- zoo::na.locf(tbl$Longitude, na.rm=FALSE, fromLast=TRUE)
+  tbl$Latitude <- zoo::na.locf(tbl$Latitude, na.rm=FALSE, fromLast=TRUE)
   # NOTE: BAM1020s don't have voltage data
-  if ( monitorType == "EBAM" ) df$Sys..Volts <- zoo::na.locf(df$Sys..Volts, na.rm=FALSE, fromLast=TRUE)
-  if ( monitorType == "ESAM" ) df$System.Volts <- zoo::na.locf(df$System.Volts, na.rm=FALSE, fromLast=TRUE)
+  if ( monitorType == "EBAM" ) tbl$Sys..Volts <- zoo::na.locf(tbl$Sys..Volts, na.rm=FALSE, fromLast=TRUE)
+  if ( monitorType == "ESAM" ) tbl$System.Volts <- zoo::na.locf(tbl$System.Volts, na.rm=FALSE, fromLast=TRUE)
   
   logger.debug("Removing %d 'GPS' records from raw data", sum(gpsMask))
-  df <- df[!gpsMask,]
+  tbl <- tbl[!gpsMask,]
   
   
-  logger.debug('Retaining %d rows of raw %s measurements', nrow(df), monitorType)
+  logger.debug('Retaining %d rows of raw %s measurements', nrow(tbl), monitorType)
 
-  return(df)
+  return(tbl)
   
 }
