@@ -1,7 +1,7 @@
 #' @keywords EPA
 #' @export
 #' @title Create EPA Data Dataframe
-#' @param df an EPA raw dataframe after metadata enhancement
+#' @param tbl an EPA raw tibble after metadata enhancement
 #' @description After addtional columns(i.e. \code{datetime}, and \code{monitorID}) 
 #' have been applied to an EPA dataframe, we are ready to
 #' extract the PM2.5 values and store them in a \code{data} dataframe
@@ -13,14 +13,20 @@
 #' 
 #' @return A \code{data} dataframe for use in a \emph{ws_monitor} object.
 
-epa_createDataDataframe <- function(df) {
+epa_createDataDataframe <- function(tbl) {
 
-  subDF <- df[,c("monitorID","datetime","Sample Measurement")]
-  # The data file will refer to any of the original instrument's readings, the bulk of the information.
+  # Create a column with the datetime
+  tbl$datetime <- lubridate::ymd_hms(paste0(tbl$`Date GMT`,' ',tbl$`Time GMT`,':00'))
+
+  # NOTE:  Add monitorID to match what is done in epa_createMetaDataframes().
+  
+  tbl$siteID <- paste0(tbl$`State Code`,tbl$`County Code`,tbl$`Site Num`)
+  tbl$instrumentID <- sprintf("%02d", as.numeric(tbl$POC))
+  tbl$monitorID <- paste(tbl$siteID, tbl$instrumentID, sep='_')
   
   # "melt" the data frame into long-format data
   # The "melt" function will turn the column names into their own column and the rest of the data into a second.
-  melted <- reshape2::melt(data=subDF, id.vars = c("datetime","monitorID"), measure.vars="Sample Measurement")
+  melted <- reshape2::melt(data=tbl, id.vars = c("datetime","monitorID"), measure.vars="Sample Measurement")
   
   # Sanity check -- only one pm25DF measure per hour
   valueCountPerCell <- reshape2::dcast(melted, datetime ~ monitorID, length)
@@ -31,7 +37,7 @@ epa_createDataDataframe <- function(df) {
   pm25DF <- reshape2::dcast(melted, datetime ~ monitorID, stats::median)
   
   # create a dataframe for hours
-  hourlyDF <- data.frame(seq(min(melted$datetime),max(melted$datetime),by="hours"))
+  hourlyDF <- data.frame(seq(min(melted$datetime), max(melted$datetime), by="hours"))
   names(hourlyDF) <- "datetime"
   
   # combine the two dataframes together by doing a left join
