@@ -27,7 +27,9 @@
 #' @seealso \code{\link{wrcc_createMetaDataframe}}
 #' @seealso \code{\link{wrcc_createDataDataframe}}
 
-wrccDump_createMonitorObject <- function(filepath, clusterDiameter=1000, existingMeta=NULL) {
+wrccDump_createMonitorObject <- function(filepath,
+                                         clusterDiameter=1000,
+                                         existingMeta=NULL) {
 
   logger.info(" ----- wrccDump_createMonitorObject() ----- ")
   
@@ -36,21 +38,21 @@ wrccDump_createMonitorObject <- function(filepath, clusterDiameter=1000, existin
   
   # Special parsing for dump files as the format is different from the WRCC CSV webservice
   logger.debug("Parsing data ...")
-  dfList <- wrccDump_parseData(fileString)
+  tblList <- wrccDump_parseData(fileString)
   
   # empty list for ws_monitor objects
   monitorList <- list()
   
-  # Loop over monitor dataframe list (mostly verbatim from wrcc_createMonitorObject)
-  for ( name in names(dfList) ) {
+  # Loop over monitor tibble list (mostly verbatim from wrcc_createMonitorObject)
+  for ( name in names(tblList) ) {
   
     logger.info("Processing data for %s ...", name)
     
-    df <- dfList[[name]]
+    tbl <- tblList[[name]]
     
-    # Apply monitor-appropriate QC to the dataframe
+    # Apply monitor-appropriate QC to the tibble
     logger.debug("Applying QC logic ...")
-    result <- try( df <- wrcc_qualityControl(df),
+    result <- try( tbl <- wrcc_qualityControl(tbl),
                    silent=TRUE ) # don't show errors
     
     if ( "try-error" %in% class(result) ) {
@@ -60,24 +62,24 @@ wrccDump_createMonitorObject <- function(filepath, clusterDiameter=1000, existin
     }
     
     # See if anything gets through QC
-    if ( nrow(df) == 0 ) {
+    if ( nrow(tbl) == 0 ) {
       logger.warn("No data remaining after QC")
       next
     }
     
     # Add clustering information to identify unique deployments
     logger.debug("Clustering ...")
-    df <- addClustering(df, lonVar='GPSLon', latVar='GPSLat', clusterDiameter=clusterDiameter)
+    tbl <- addClustering(tbl, lonVar='GPSLon', latVar='GPSLat', clusterDiameter=clusterDiameter)
     
     # Create 'meta' dataframe of site properties organized as monitorID-by-property
     # NOTE:  This step will create a uniformly named set of properties and will
     # NOTE:  add site-specific information like timezone, elevation, address, etc.
     logger.debug("Creating 'meta' dataframe ...")
-    meta <- wrcc_createMetaDataframe(df, existingMeta)
+    meta <- wrcc_createMetaDataframe(tbl, "", "WRCC_DUMPFILE", existingMeta=existingMeta)
     
     # Create 'data' dataframe of PM2.5 values organized as time-by-monitorID
     logger.debug("Creating 'data' dataframe ...")
-    data <- wrcc_createDataDataframe(df, meta)
+    data <- wrcc_createDataDataframe(tbl, meta)
     
     # Create the 'ws_monitor' object
     ws_monitor <- list(meta=meta, data=data)
