@@ -1,10 +1,10 @@
 #' @keywords WRCC
 #' @export
 #' @title Create WRCC Data Dataframe
-#' @param df single site WRCC dataframe created by \code{wrcc_clustering()}
-#' @param meta WRCC meta dataframe created by \code{wrcc_createMetaDataframe()}
-#' @description After quality control has been applied to an WRCC dataframe,
-#' we can extract the PM2.5 values and store them in a \code{data} dataframe
+#' @param tbl single site WRCC tibble created by \code{wrcc_clustering()}
+#' @param meta WRCC meta datafra,e created by \code{wrcc_createMetaDataframe()}
+#' @description After quality control has been applied to an WRCC tibble,
+#' we can extract the PM2.5 values and store them in a \code{data} tibble
 #' organized as time-by-deployment (aka time-by-site).
 #' 
 #' The first column of the returned dataframe is named \code{'datetime'} and
@@ -14,12 +14,18 @@
 #' @return A \code{data} dataframe for use in a \emph{ws_monitor} object.
 
 
-wrcc_createDataDataframe <- function(df, meta) {
+wrcc_createDataDataframe <- function(tbl, meta) {
   
-  # Sanity check -- df must have datetime
-  if ( !'datetime' %in% names(df) ) {
-    logger.error("No 'datetime' column found in 'df' dataframe with columns: %s", paste0(names(df), collapse=", "))
-    stop(paste0("No 'datetime' column found in 'df' dataframe."))
+  # Sanity check -- tbl must have deploymentID
+  if ( !'deploymentID' %in% names(tbl) ) {
+    logger.error("No 'deploymentID' column found in 'tbl' tibble with columns: %s", paste0(names(tbl), collapse=", "))
+    stop(paste0("No 'deploymentID' column found in 'tbl' tibble.  Have you run addClustering()?"))
+  }
+  
+  # Sanity check -- tbl must have datetime
+  if ( !'datetime' %in% names(tbl) ) {
+    logger.error("No 'datetime' column found in 'tbl' tibble with columns: %s", paste0(names(tbl), collapse=", "))
+    stop(paste0("No 'datetime' column found in 'tbl' tibble."))
   }
   
   # Sanity check -- meta must have a monitorType
@@ -30,20 +36,20 @@ wrcc_createDataDataframe <- function(df, meta) {
   
   monitorType <- unique(meta$monitorType)
   
-  # Sanity check -- df must have only one monitorType
+  # Sanity check -- only a single monitorType is allowed
   if ( length(monitorType) > 1 ) {
     logger.error("Multiple monitor types found in 'meta' dataframe: %s", paste0(monitorType, collapse=", "))
     stop(paste0("Multiple monitor types found in 'meta' dataframe."))
   }
   
-  # Sanity check -- df must have deploymentID
-  if ( !'deploymentID' %in% names(df) ) {
-    logger.error("No 'deploymentID' column found in 'df' dataframe with columns: %s", paste0(names(df), collapse=", "))
-    stop(paste0("No 'deploymentID' column found in 'df' dataframe.  Have you run addClustering()?"))
+  # Create monitorID the same way we did in airsis_createMetaDataframe()
+  # Should only have a single instrumentID
+  instrumentIDs <- sort(unique(meta$instrumentID))
+  if ( length(instrumentIDs) > 1 ) {
+    logger.warn('Multiple instrumentIDs encountered: %s', paste0(instrumentIDs,collapse=", "))
   }
-  
-  # Create monitorID the same way we did in wrcc_createMetaDataframe()
-  df$monitorID <- paste0( make.names(df$monitorName), '__', df$deploymentID )
+  instrumentID <- instrumentIDs[1]
+  tbl$monitorID <- paste(as.character(tbl$deploymentID), instrumentID, sep='_')
   
   if ( monitorType == 'EBAM' ) {
     pm25Var <- 'ConcRT'
@@ -55,8 +61,8 @@ wrcc_createDataDataframe <- function(df, meta) {
   }
   
   # Create minimal subset with the the variables we need for rows, columns and data
-  subDF <- df[,c('datetime','monitorID',pm25Var)]
-  melted <- reshape2::melt(subDF, id.vars=c('datetime','monitorID'), measure.vars=pm25Var)
+  subTbl <- tbl[,c('datetime','monitorID',pm25Var)]
+  melted <- reshape2::melt(subTbl, id.vars=c('datetime','monitorID'), measure.vars=pm25Var)
   
   # Unit conversion as needed (mg/m3 ==> ug/m3)
   if ( monitorType == 'EBAM' ) melted$value <- melted$value * 1 # no conversion needed
@@ -75,15 +81,15 @@ wrcc_createDataDataframe <- function(df, meta) {
   pm25DF <- pm25DF[,c('datetime',meta$monitorID)]
 
   # Create an empty hourlyDF dataframe with a full time axis (no missing hours)
-  datetime <- seq(min(df$datetime), max(df$datetime), by="hours")
+  datetime <- seq(min(tbl$datetime), max(tbl$datetime), by="hours")
   hourlyDF <- data.frame(datetime=datetime)
   
   # Merge pm25DF into the houlyDF dataframe, inserting NA's where necessary
   # NOTE:  dplyr returns objects of class "tbl_df" which can be confusing. We undo that.
-  data <- as.data.frame( dplyr::left_join(hourlyDF, pm25DF, by='datetime') )
+  data <- as.data.frame( dplyr::left_join(hourlyDF, pm25DF, by='datetime'), stringsAsFactors=FALSE )
 
   logger.info("Created 'data' dataframe with %d rows and %d columns", nrow(data), ncol(data))
   
-  return(as.data.frame(data))
+  return(data)
   
 }
