@@ -5,8 +5,10 @@
 #' @param enddate desired end date (integer or character representing YYYYMMDD[HH])
 #' @param unitID station identifier (will be upcased)
 #' @param clusterDiameter diameter in meters used to determine the number of clusters (see \code{addClustering})
+#' @param zeroMinimum logical specifying whether to convert negative values to zero
 #' @param baseUrl base URL for data queries
 #' @param saveFile optional filename where raw CSV will be written
+#' @param ... additional parameters are passed to type-specific QC functions
 #' @return A \emph{ws_monitor} object with WRCC data.
 #' @description Obtains monitor data from an WRCC webservice and converts
 #' it into a quality controlled, metadata enhanced \emph{ws_monitor} object
@@ -23,6 +25,22 @@
 #'  \item{reshape data into deployment-by-property \code{meta} and and time-by-deployment \code{data} dataframes}
 #' }
 #' 
+#' QC parameters that can be passed in the \code{\dots} include the following
+#' valid data ranges as taken from \code{wrcc_EBAMQualityControl()}:
+#' 
+#' \itemize{
+#' \item{\code{valid_Longitude=c(-180,180)}}
+#' \item{\code{valid_Latitude=c(-90,90)}}
+#' \item{\code{remove_Lon_zero = TRUE}}
+#' \item{\code{remove_Lat_zero = TRUE}}
+#' \item{\code{valid_Flow = c(16.7*0.95,16.7*1.05)}}
+#' \item{\code{valid_AT = c(-Inf,45)}}
+#' \item{\code{valid_RHi = c(-Inf,45)}}
+#' \item{\code{valid_Conc = c(-Inf,5000)}}
+#' }
+#' 
+#' Note that appropriate values for QC thresholds will depend on the type of monitor.
+#' 
 #' @note The downloaded CSV may be saved to a local file by providing an argument to the \code{saveFile} parameter.
 #' @seealso \code{\link{wrcc_downloadData}}
 #' @seealso \code{\link{wrcc_parseData}}
@@ -36,12 +54,25 @@
 #' monitorLeaflet(sm13)
 #' }
 
-wrcc_createMonitorObject <- function(startdate=20020101,
-                                     enddate=strftime(lubridate::now(),"%Y%m%d",tz="UTC"),
+wrcc_createMonitorObject <- function(startdate=strftime(lubridate::now(),"%Y010100",tz="UTC"),
+                                     enddate=strftime(lubridate::now(),"%Y%m%d23",tz="UTC"),
                                      unitID=NULL,
                                      clusterDiameter=1000,
+                                     zeroMinimum=TRUE,
                                      baseUrl="https://wrcc.dri.edu/cgi-bin/wea_list2.pl",
-                                     saveFile=NULL) {
+                                     saveFile=NULL,
+                                     ...) {
+  
+  # FOR TESTING
+  if ( FALSE ) {
+    startdate <- strftime(lubridate::now(),"%Y010101",tz="UTC")
+    enddate <- strftime(lubridate::now(),"%Y%m%d23",tz="UTC")
+    unitID <- 'sm21'
+    clusterDiameter <- 1000
+    zeroMinimum <- TRUE
+    baseUrl <- "https://wrcc.dri.edu/cgi-bin/wea_list2.pl"
+    saveFile <- NULL
+  }
   
   # Sanity checks
   if ( is.null(unitID) ) {
@@ -76,41 +107,43 @@ wrcc_createMonitorObject <- function(startdate=20020101,
     # NOTE:  Processing continues even if we fail to write the local file
   }
   
-  # Read csv raw data into a dataframe
+  # Read csv raw data into a tibble
   logger.debug("Parsing data ...")
-  df <- wrcc_parseData(fileString)
+  tbl <- wrcc_parseData(fileString)
   
-  # Apply monitor-appropriate QC to the dataframe
+  # Apply monitor-appropriate QC to the tibble
   logger.debug("Applying QC logic ...")
-  df <- wrcc_qualityControl(df)
+  tbl <- wrcc_qualityControl(tbl, ...)
   
   # See if anything gets through QC
-  if ( nrow(df) == 0 ) {
+  if ( nrow(tbl) == 0 ) {
     logger.warn("No data remaining after QC")
     stop("No data remaining after QC")
   }
   
   # Add clustering information to identify unique deployments
   logger.debug("Clustering ...")
-  df <- addClustering(df, lonVar='GPSLon', latVar='GPSLat', clusterDiameter=clusterDiameter)
+  tbl <- addClustering(tbl, lonVar='GPSLon', latVar='GPSLat', clusterDiameter=clusterDiameter)
   
   # Create 'meta' dataframe of site properties organized as monitorID-by-property
   # NOTE:  This step will create a uniformly named set of properties and will
   # NOTE:  add site-specific information like timezone, elevation, address, etc.
   logger.debug("Creating 'meta' dataframe ...")
-  meta <- wrcc_createMetaDataframe(df)
+  meta <- wrcc_createMetaDataframe(tbl, unitID, 'WRCC')
   
   # Create 'data' dataframe of PM2.5 values organized as time-by-monitorID
   logger.debug("Creating 'data' dataframe ...")
-  data <- wrcc_createDataDataframe(df, meta)
+  data <- wrcc_createDataDataframe(tbl, meta)
   
   # Create the 'ws_monitor' object
   ws_monitor <- list(meta=meta, data=data)
   ws_monitor <- structure(ws_monitor, class = c("ws_monitor", "list"))
 
   # Reset all negative values that made it through QC to zero
-  logger.debug("Reset negative valus to zero ...")
-  ws_monitor <- monitor_replaceData(ws_monitor, data < 0, 0)
+  if ( zeroMinimum ) {
+    logger.debug("Reset negative valus to zero ...")
+    ws_monitor <- monitor_replaceData(ws_monitor, data < 0, 0)
+  }
   
   return(ws_monitor)
   
